@@ -20,7 +20,7 @@ arabic_lboxinit(PangoFont  *font);
 /* glyph2 is the next glyph in line; if there is none, put in NULL 
  */
 void
-arabic_lbox_recode(PangoXSubfont* subfont,int* glyph,int* glyph2,
+arabic_lbox_recode(PangoXSubfont* subfont,gunichar* glyph,int* glyph2,
                    PangoXSubfont* lboxfonts);
 
 
