@@ -20,7 +20,6 @@
  */
 
 #include <stdlib.h>
-#include <ctype.h>
 #include <math.h>
 #include <string.h>
 
@@ -179,7 +178,7 @@ pango_font_description_get_family (const PangoFontDescription *desc)
  * Sets the style field of a #PangoFontDescription. The
  * #PangoStyle enumeration describes whether the font is slanted and
  * the manner in which it is slanted; it can be either
- * %PANGO_STYLE_NORMAL, %PANGO_STYLE_ITALIC, or %PANGO_STYLE_OBLIQUE.
+ * #PANGO_STYLE_NORMAL, #PANGO_STYLE_ITALIC, or #PANGO_STYLE_OBLIQUE.
  * Most fonts will either have a italic style or an oblique
  * style, but not both, and font matching in Pango will 
  * match italic specifications with oblique fonts and vice-versa
@@ -219,8 +218,8 @@ pango_font_description_get_style (const PangoFontDescription *desc)
  * @desc: a #PangoFontDescription
  * @variant: the variant type for the font description.
  * 
- * Sets the variant field of a font description. The %PangoVariant
- * can either by %PANGO_VARIANT_NORMAL or %PANGO_VARIANT_SMALL_CAPS.
+ * Sets the variant field of a font description. The #PangoVariant
+ * can either be %PANGO_VARIANT_NORMAL or %PANGO_VARIANT_SMALL_CAPS.
  **/
 void
 pango_font_description_set_variant (PangoFontDescription *desc,
@@ -331,7 +330,7 @@ pango_font_description_get_stretch (const PangoFontDescription *desc)
  * pango_font_description_set_size:
  * @desc: a #PangoFontDescription
  * @size: the size for the font description in pango units.
- *        (%PANGO_SCALE pango units equals one point)
+ *        There are #PANGO_SCALE Pango units in one device unit (device unit is a point, for font sizes).
  * 
  * Sets the size field of a font description.
  **/
@@ -353,10 +352,10 @@ pango_font_description_set_size (PangoFontDescription *desc,
  * See pango_font_description_get_size().
  * 
  * Return value: the size field for the font description in pango
- *   units.  (%PANGO_SCALE pango units equals one point). Returns 0 if
- *   the stretch field has not previously been set.
- *   pango_font_description_get_set_fields() to find out if the field
- *   was explicitely set or not.
+ *   units.  (There are #PANGO_SCALE pango units in one device unit &mdash;
+ *   for fonts, font points are the device unit.) Returns 0 if the stretch field has not
+ *   previously been set.  pango_font_description_get_set_fields() to
+ *   find out if the field was explicitely set or not.
  **/
 gint
 pango_font_description_get_size (const PangoFontDescription *desc)
@@ -443,6 +442,8 @@ pango_font_description_merge (PangoFontDescription       *desc,
     desc->stretch = desc_to_merge->stretch;
   if (new_mask & PANGO_FONT_MASK_SIZE)
     desc->size = desc_to_merge->size;
+
+  desc->mask |= new_mask;
 }
 
 /**
@@ -484,6 +485,8 @@ pango_font_description_merge_static (PangoFontDescription       *desc,
     desc->stretch = desc_to_merge->stretch;
   if (new_mask & PANGO_FONT_MASK_SIZE)
     desc->size = desc_to_merge->size;
+
+  desc->mask |= new_mask;
 }
 
 static gint
@@ -652,7 +655,8 @@ pango_font_description_hash (const PangoFontDescription *desc)
  * Frees a font description returned from pango_font_describe()
  * or pango_font_description_copy().
  **/
-void pango_font_description_free  (PangoFontDescription  *desc)
+void 
+pango_font_description_free  (PangoFontDescription  *desc)
 {
   if (desc)
     {
@@ -758,11 +762,11 @@ getword (const char *str, const char *last, size_t *wordlen)
 {
   const char *result;
   
-  while (last > str && isspace (*(last - 1)))
+  while (last > str && g_ascii_isspace (*(last - 1)))
     last--;
 
   result = last;
-  while (result > str && !isspace (*(result - 1)))
+  while (result > str && !g_ascii_isspace (*(result - 1)))
     result--;
 
   *wordlen = last - result;
@@ -806,6 +810,8 @@ pango_font_description_from_string (const char *str)
                PANGO_FONT_MASK_STRETCH;
   
   desc->family_name = NULL;
+  desc->static_family = FALSE;
+  
   desc->style = PANGO_STYLE_NORMAL;
   desc->weight = PANGO_WEIGHT_NORMAL;
   desc->variant = PANGO_VARIANT_NORMAL;
@@ -848,16 +854,16 @@ pango_font_description_from_string (const char *str)
   /* Remainder (str => p) is family list. Trim off trailing commas and leading and trailing white space
    */
 
-  while (last > str && isspace (*(last - 1)))
+  while (last > str && g_ascii_isspace (*(last - 1)))
     last--;
 
   if (last > str && *(last - 1) == ',')
     last--;
 
-  while (last > str && isspace (*(last - 1)))
+  while (last > str && g_ascii_isspace (*(last - 1)))
     last--;
 
-  while (isspace (*str))
+  while (g_ascii_isspace (*str))
     str++;
 
   if (str != last)
@@ -1191,7 +1197,7 @@ pango_font_metrics_unref (PangoFontMetrics *metrics)
  * actual drawn ink. It is necessary to lay out the text to figure
  * where the ink will be.)
  * 
- * Return value: the ascent, in pango units. (1 point == %PANGO_SCALE pango units.)
+ * Return value: the ascent, in pango units. (1 point == #PANGO_SCALE pango units.)
  **/
 int
 pango_font_metrics_get_ascent (PangoFontMetrics *metrics)
@@ -1211,7 +1217,7 @@ pango_font_metrics_get_ascent (PangoFontMetrics *metrics)
  * actual drawn ink. It is necessary to lay out the text to figure
  * where the ink will be.)
  * 
- * Return value: the descent, in pango units. (1 point == %PANGO_SCALE pango units.)
+ * Return value: the descent, in pango units. (1 point == #PANGO_SCALE pango units.)
  **/
 int
 pango_font_metrics_get_descent (PangoFontMetrics *metrics)
@@ -1230,7 +1236,7 @@ pango_font_metrics_get_descent (PangoFontMetrics *metrics)
  * determining the initial size for a window. Actual characters in
  * text will be wider and narrower than this.
  * 
- * Return value: the character width, in pango units. (1 point == %PANGO_SCALE pango units.)
+ * Return value: the character width, in pango units. (1 point == #PANGO_SCALE pango units.)
  **/
 int
 pango_font_metrics_get_approximate_char_width (PangoFontMetrics *metrics)
@@ -1251,7 +1257,7 @@ pango_font_metrics_get_approximate_char_width (PangoFontMetrics *metrics)
  * is generally somewhat more accurate than the result of
  * pango_font_metrics_get_approximate_digit_width().
  * 
- * Return value: the digit width, in pango units. (1 point == %PANGO_SCALE pango units.)
+ * Return value: the digit width, in pango units. (1 point == #PANGO_SCALE pango units.)
  **/
 int
 pango_font_metrics_get_approximate_digit_width (PangoFontMetrics *metrics)
