@@ -32,7 +32,8 @@ typedef struct _PangoXftFont PangoXftFont;
 struct _PangoXftFont
 {
   PangoFont parent_instance;
-  
+
+  XftPattern *font_pattern;
   XftFont *xft_font;
   PangoFont *mini_font;
   PangoFontMap *fontmap;
@@ -47,8 +48,7 @@ struct _PangoXftFont
 };
 
 PangoXftFont * _pango_xft_font_new              (PangoFontMap                *font,
-						 const PangoFontDescription  *description,
-						 XftFont                     *xft_font);
+						 XftPattern                  *pattern);
 void           _pango_xft_font_map_cache_add    (PangoFontMap                *fontmap,
 						 PangoXftFont                *xfont);
 void           _pango_xft_font_map_add          (PangoFontMap                *fontmap,
@@ -64,6 +64,9 @@ void           _pango_xft_font_map_get_info     (PangoFontMap                *fo
 						 Display                    **display,
 						 int                         *screen);
 
+PangoFontDescription * _pango_xft_font_desc_from_pattern (XftPattern *pattern,
+							  gboolean    include_size);
+
 G_END_DECLS
 
 #endif /* __PANGOXFT_PRIVATE_H__ */
